# EcoOpen

Wellcome to the EcoOpen python package. In this notebook we will show you how to use the EcoOpen package to:

- Search for scientific articles registered in Crossref;
- Download the full text of the articles;
- Extract the text from the articles;
- Find open data in the articles;
- Create a report with the results.

EcoOpen can use the Crossref API to search for articles and download the full text. It can also use LLMs (Large Language Models) to "understand" portions of the text and extract information from it. It can be used to search for open data in scientific articles and to create reports with the results. 

EcoOpen was designed as spiritual succesor to [oddpub](https://github.com/quest-bih/oddpub).

## Example
Check examples folder for a Jupyter notebook with an example of how to use EcoOpen. [notebook](https://github.com/sciom/EcoOpenPy/blob/main/examples/example.ipynb)

R wrapper for EcoOpen is available at [EcoOpenR](https://github.com/sciom/EcoOpenR).

